/**
 * Inspector Controls
 */

import times from "lodash/times";
import BoxShadowControl from "../../../utils/components/box-shadow";
import FontIconPicker from "@fonticonpicker/react-fonticonpicker";
import ResponsiveBlocksIcon from "../../../ResponsiveBlocksIcon.json";
import renderSVG from "../../../renderIcon";
import fontOptions from "../../../utils/googlefonts";
import { loadGoogleFont } from "../../../utils/font";

// Setup the block
const { __ } = wp.i18n;
const { Component, Fragment } = wp.element;

// Import block components
const {
  InspectorControls,
  PanelColorSettings,
  MediaUpload,
  ColorPalette,
} = wp.editor;

// Import Inspector components
const {
  PanelBody,
  RangeControl,
  SelectControl,
  ToggleControl,
  BaseControl,
  Button,
} = wp.components;

let svg_icons = Object.keys(ResponsiveBlocksIcon);

/**
 * Create an Inspector Controls wrapper Component
 */
export default class Inspector extends Component {
  constructor(props) {
    super(...arguments);
    this.onSelectTestImage = this.onSelectTestImage.bind(this);
    this.getImageName = this.getImageName.bind(this);
    this.onRemoveTestImage = this.onRemoveTestImage.bind(this);
    this.onRemoveImage = this.onRemoveImage.bind(this);
    this.onSelectImage = this.onSelectImage.bind(this);
  }
  /*
   * Event to set Image as while adding.
   */
  onSelectTestImage(media, index) {
    const { cardsArray } = this.props.attributes;
    const { setAttributes } = this.props;

    let imag_url = null;
    if (!media || !media.url) {
      imag_url = null;
    } else {
      imag_url = media;
    }

    if (!media.type || "image" !== media.type) {
      imag_url = null;
    }

    const newItems = cardsArray.map((item, thisIndex) => {
      if (index === thisIndex) {
        (item["image"] = imag_url), (item["imageUrl"] = imag_url);
      }
      return item;
    });

    setAttributes({
      cardsArray: newItems,
    });
  }

  /*
   * Event to set Image as null while removing.
   */
  onRemoveTestImage(index) {
    const { cardsArray } = this.props.attributes;
    const { setAttributes } = this.props;

    const newItems = cardsArray.map((item, thisIndex) => {
      if (index === thisIndex) {
        item["image"] = null;
      }
      return item;
    });

    setAttributes({
      cardsArray: newItems,
    });
  }

  /*
   * Event to set Image selectot label.
   */
  getImageName(image) {
    const { cardsArray } = this.props.attributes;

    let image_name = __("Select Image");
    if (image) {
      if (image.url == null || image.url == "") {
        image_name = __("Select Image");
      } else {
        image_name = __("Replace Image");
      }
    }
    return image_name;
  }

  /*
   * Event to set Image as null while removing.
   */
  onRemoveImage() {
    const { setAttributes } = this.props;

    setAttributes({ backgroundImage: null });
  }

  /*
   * Event to set Image as while adding.
   */
  onSelectImage(media) {
    const { setAttributes } = this.props;

    if (!media || !media.url) {
      setAttributes({ backgroundImage: null });
      return;
    }

    if (!media.type || "image" != media.type) {
      return;
    }

    setAttributes({ backgroundImage: media });
  }
  render() {
    // Setup the attributes
    const {
      attributes: {
        count,
        gutter,
        cardsArray,
        textColor,
        itemBackgroundColor,
        buttonTarget,
        borderStyle,
        borderWidth,
        borderRadius,
        borderColor,
        boxShadowColor,
        boxShadowHOffset,
        boxShadowVOffset,
        boxShadowBlur,
        boxShadowSpread,
        boxShadowPosition,
        titleSpace,
        subtitleSpace,
        contentSpace,
        buttonSpace,
        buttonColor,
        buttonTextColor,
        stack,
        opacity,
        resshowImage,
        imageopacity,
        backgroundType,
        backgroundImage,
        gradientDirection,
        colorLocation1,
        colorLocation2,
        backgroundColor1,
        backgroundColor2,
        imageSize,
        imagePosition,
        imageRepeat,
        thumbsize,
        imageheight,
        blockzindex,
        blockmargin,
        icon,
        iconPosition,
        icon_color,
        buttonhColor,
        buttonhTextColor,
        butopacity,
        vPadding,
        hPadding,
        vMargin,
        hMargin,
        butborderWidth,
        butborderRadius,
        butborderStyle,
        buttonSize,
        buttonbackgroundType,
        buttongradientDirection,
        buttoncolorLocation1,
        buttoncolorLocation2,
        buttonbackgroundColor1,
        buttonbackgroundColor2,
        icon_hcolor,
        subFontFamily,
        subLineHeight,
        subFontWeight,
        subFontSize,
        headingFontFamily,
        headingLineHeight,
        headingFontWeight,
        headingFontSize,
        contentFontFamily,
        contentLineHeight,
        contentFontWeight,
        contentFontSize,
        contenttopSpace,
        blockbotmargin,
        blockleftmargin,
        blockrightmargin,
        bgimageSize,
        bgimagePosition,
        bgimageRepeat,
        bgthumbsize,
      },
      setAttributes,
    } = this.props;

    // Font Weight Options
    const fontWeightOptions = [
      {
        value: "100",
        label: __("100", "easy-gtblocks"),
      },
      {
        value: "200",
        label: __("200", "easy-gtblocks"),
      },
      {
        value: "300",
        label: __("300", "easy-gtblocks"),
      },
      {
        value: "400",
        label: __("400", "easy-gtblocks"),
      },
      {
        value: "500",
        label: __("500", "easy-gtblocks"),
      },
      {
        value: "600",
        label: __("600", "easy-gtblocks"),
      },
      {
        value: "700",
        label: __("700", "easy-gtblocks"),
      },
      {
        value: "800",
        label: __("800", "easy-gtblocks"),
      },
      {
        value: "900",
        label: __("900", "easy-gtblocks"),
      },
    ];

    // Button size values
    const buttonSizeOptions = [
      {
        value: "easy-gtblocks-button-size-small",
        label: __("Small"),
      },
      {
        value: "easy-gtblocks-button-size-medium",
        label: __("Medium"),
      },
      {
        value: "easy-gtblocks-button-size-large",
        label: __("Large"),
      },
      {
        value: "easy-gtblocks-button-size-extralarge",
        label: __("Extra Large"),
      },
    ];

    // Background Type Options
    const buttonbackgroundTypeOptions = [
      { value: "none", label: __("None", "easy-gtblocks") },
      { value: "color", label: __("Color", "easy-gtblocks") },
      {
        value: "gradient",
        label: __("Gradient", "easy-gtblocks"),
      },
    ];
    // Image Size Options
    const imageSizeOptions = [
      {
        value: "thumbnail",
        label: __("Thumbnail", "easy-gtblocks"),
      },
      {
        value: "medium",
        label: __("Medium", "easy-gtblocks"),
      },
      { value: "large", label: __("Large", "easy-gtblocks") },
      { value: "full", label: __("Full", "easy-gtblocks") },
    ];

    const tmControls = (index) => {
      let image_val = null;
      if (cardsArray[index] && typeof cardsArray[index] !== "undefined") {
        image_val = cardsArray[index]["image"];
      }
      return (
        <PanelBody
          key={index}
          title={__("Image") + " " + (index + 1) + " " + __("Settings")}
          initialOpen={true}
          className={"rbea-repeater-panel"}
        >
          <BaseControl className="editor-bg-image-control" label={__("")}>
            <MediaUpload
              title={__("Select Image" + (index + 1))}
              onSelect={(media) => {
                this.onSelectTestImage(media, index);
              }}
              allowedTypes={["image"]}
              value={image_val}
              render={({ open }) => (
                <Button isDefault onClick={open}>
                  {this.getImageName(cardsArray[index]["image"])}
                </Button>
              )}
            />
            {image_val &&
              cardsArray[index]["image"].url !== null &&
              cardsArray[index]["image"].url !== "" && (
                <Button
                  className="rbea-rm-btn"
                  key={index}
                  onClick={(value) => {
                    this.onRemoveTestImage(index);
                  }}
                  isLink
                  isDestructive
                >
                  {__("Remove Image")}
                </Button>
              )}
          </BaseControl>
        </PanelBody>
      );
    };

    // Update color value
    const onChangeTextColor = (value) => setAttributes({ textColor: value });
    const onChangeBackgroundColor = (value) =>
      setAttributes({ itemBackgroundColor: value });

    // Background Type Options
    const backgroundTypeOptions = [
      { value: "none", label: __("None", "easy-gtblocks") },
      { value: "color", label: __("Color", "easy-gtblocks") },
      {
        value: "gradient",
        label: __("Gradient", "easy-gtblocks"),
      },
      { value: "image", label: __("Image", "easy-gtblocks") },
    ];

    return (
      <InspectorControls key="inspector">
        <PanelBody
          title={__("General", "easy-gtblocks")}
          initialOpen={false}
        >
          <RangeControl
            label={__("Number of Cards", "easy-gtblocks")}
            value={count}
            onChange={(newCount) => {
              let clonecardsArray = [...cardsArray];
              if (clonecardsArray.length < newCount) {
                const incsubtitle = Math.abs(newCount - clonecardsArray.length);

                {
                  times(incsubtitle, (n) => {
                    clonecardsArray.push({
                      title: "Title ",
                      subtitle: "Subtitle",
                      content:
                        "Description for this block. Use this space for describing your block. Any text will do. Description for this block. You can use this space for describing your block.",
                      button: "Button" + newCount,
                    });
                  });
                }
                setAttributes({ cardsArray: clonecardsArray });
              } else {
                const incsubtitle = Math.abs(newCount - clonecardsArray.length);
                let data_new = clonecardsArray;
                for (var i = 0; i < incsubtitle; i++) {
                  data_new.pop();
                }
                setAttributes({ cardsArray: data_new });
              }
              setAttributes({ count: newCount });
            }}
            min={1}
            max={4}
            step={1}
          />
          <SelectControl
            label={__("Stack on", "easy-gtblocks")}
            value={stack}
            options={[
              {
                value: "none",
                label: __("None", "easy-gtblocks"),
              },
              {
                value: "tablet",
                label: __("Tablet", "easy-gtblocks"),
              },
              {
                value: "mobile",
                label: __("Mobile", "easy-gtblocks"),
              },
            ]}
            onChange={(value) => setAttributes({ stack: value })}
            help={__(
              "Note: Choose on what breakpoint the columns will stack.",
              "easy-gtblocks"
            )}
          />
          <RangeControl
            label={__("Z-Index", "easy-gtblocks")}
            value={blockzindex}
            onChange={(value) =>
              setAttributes({ blockzindex: value !== undefined ? value : 1 })
            }
            min={0}
            max={9999}
            allowReset
          />
        </PanelBody>
        <PanelBody
          title={__("Image", "easy-gtblocks")}
          initialOpen={false}
        >
          <ToggleControl
            label={__("Enable Image", "easy-gtblocks")}
            checked={resshowImage}
            onChange={(value) => setAttributes({ resshowImage: !resshowImage })}
          />
        </PanelBody>
        {resshowImage && (
          <PanelBody
            title={__("Select Image", "easy-gtblocks")}
            initialOpen={false}
          >
            {times(count, (n) => tmControls(n))}
          </PanelBody>
        )}
        {resshowImage && (
          <PanelBody
            title={__("Image Settings", "easy-gtblocks")}
            initialOpen={false}
          >
            <SelectControl
              label={__("Image Size", "easy-gtblocks")}
              value={imageSize}
              onChange={(value) => setAttributes({ imageSize: value })}
              options={imageSizeOptions}
            />

            <SelectControl
              label={__("Image Position", "easy-gtblocks")}
              value={imagePosition}
              onChange={(value) => setAttributes({ imagePosition: value })}
              options={[
                {
                  value: "top left",
                  label: __("Top Left", "easy-gtblocks"),
                },
                {
                  value: "top center",
                  label: __("Top Center", "easy-gtblocks"),
                },
                {
                  value: "top right",
                  label: __("Top Right", "easy-gtblocks"),
                },
                {
                  value: "center left",
                  label: __("Center Left", "easy-gtblocks"),
                },
                {
                  value: "center center",
                  label: __("Center Center", "easy-gtblocks"),
                },
                {
                  value: "center right",
                  label: __("Center Right", "easy-gtblocks"),
                },
                {
                  value: "bottom left",
                  label: __("Bottom Left", "easy-gtblocks"),
                },
                {
                  value: "bottom center",
                  label: __("Bottom Center", "easy-gtblocks"),
                },
                {
                  value: "bottom right",
                  label: __("Bottom Right", "easy-gtblocks"),
                },
              ]}
            />
            <SelectControl
              label={__("Image Repeat", "easy-gtblocks")}
              value={imageRepeat}
              onChange={(value) => setAttributes({ imageRepeat: value })}
              options={[
                {
                  value: "no-repeat",
                  label: __("No Repeat", "easy-gtblocks"),
                },
                {
                  value: "repeat",
                  label: __("Repeat", "easy-gtblocks"),
                },
                {
                  value: "repeat-x",
                  label: __("Repeat-X", "easy-gtblocks"),
                },
                {
                  value: "repeat-y",
                  label: __("Repeat-Y", "easy-gtblocks"),
                },
              ]}
            />
            <SelectControl
              label={__("Image Size", "easy-gtblocks")}
              value={thumbsize}
              onChange={(value) => setAttributes({ thumbsize: value })}
              options={[
                {
                  value: "cover",
                  label: __("Cover", "easy-gtblocks"),
                },
                {
                  value: "auto",
                  label: __("Auto", "easy-gtblocks"),
                },
                {
                  value: "contain",
                  label: __("Contain", "easy-gtblocks"),
                },
              ]}
            />
            <RangeControl
              label={__("Custom Height", "easy-gtblocks")}
              value={imageheight}
              onChange={(value) =>
                setAttributes({
                  imageheight: value !== undefined ? value : 200,
                })
              }
              min={0}
              max={1000}
              allowReset
            />
          </PanelBody>
        )}

        <PanelBody
          title={__("Column Background", "easy-gtblocks")}
          initialOpen={false}
        >
          <SelectControl
            label={__("Background Type", "easy-gtblocks")}
            value={backgroundType}
            onChange={(value) => setAttributes({ backgroundType: value })}
            options={backgroundTypeOptions}
          />
          {"color" == backgroundType && (
            <Fragment>
              <p className="responsive-setting-label">
                {__("Background Color", "easy-gtblocks")}
                <span className="components-base-control__label">
                  <span
                    className="component-color-indicator"
                    style={{ backgroundColor: itemBackgroundColor }}
                  ></span>
                </span>
              </p>
              <ColorPalette
                value={itemBackgroundColor}
                onChange={onChangeBackgroundColor}
                allowReset
              />
              <RangeControl
                label={__("Opacity", "easy-gtblocks")}
                value={opacity}
                onChange={(value) =>
                  setAttributes({
                    opacity: value !== undefined ? value : 0,
                  })
                }
                min={0}
                max={100}
                allowReset
              />
            </Fragment>
          )}
          {"gradient" == backgroundType && (
            <Fragment>
              <p className="responsive-setting-label">
                {__("Color 1", "easy-gtblocks")}
                <span className="components-base-control__label">
                  <span
                    className="component-color-indicator"
                    style={{ backgroundColor: backgroundColor1 }}
                  ></span>
                </span>
              </p>
              <ColorPalette
                value={backgroundColor1}
                onChange={(colorValue) =>
                  setAttributes({ backgroundColor1: colorValue })
                }
                allowReset
              />

              <p className="responsive-setting-label">
                {__("Color 2", "easy-gtblocks")}
                <span className="components-base-control__label">
                  <span
                    className="component-color-indicator"
                    style={{ backgroundColor: backgroundColor2 }}
                  ></span>
                </span>
              </p>
              <ColorPalette
                value={backgroundColor2}
                onChange={(colorValue) =>
                  setAttributes({ backgroundColor2: colorValue })
                }
                allowReset
              />
              <RangeControl
                label={__("Color Location 1", "easy-gtblocks")}
                value={colorLocation1}
                min={0}
                max={100}
                onChange={(value) =>
                  setAttributes({
                    colorLocation1: value !== undefined ? value : 0,
                  })
                }
              />
              <RangeControl
                label={__("Color Location 2", "easy-gtblocks")}
                value={colorLocation2}
                min={0}
                max={100}
                onChange={(value) =>
                  setAttributes({
                    colorLocation2: value !== undefined ? value : 100,
                  })
                }
              />
              <RangeControl
                label={__(
                  "Gradient Direction",
                  "easy-gtblocks"
                )}
                value={gradientDirection}
                min={0}
                max={100}
                onChange={(value) =>
                  setAttributes({
                    gradientDirection: value !== undefined ? value : 90,
                  })
                }
              />
            </Fragment>
          )}
          {"image" == backgroundType && (
            <Fragment>
              <BaseControl
                className="editor-bg-image-control"
                label={__("Background Image", "easy-gtblocks")}
              >
                <MediaUpload
                  title={__(
                    "Select Background Image",
                    "easy-gtblocks"
                  )}
                  onSelect={this.onSelectImage}
                  allowedTypes={["image"]}
                  value={backgroundImage}
                  render={({ open }) => (
                    <Button isDefault onClick={open}>
                      {!backgroundImage
                        ? __(
                            "Select Background Image",
                            "easy-gtblocks"
                          )
                        : __("Replace image", "easy-gtblocks")}
                    </Button>
                  )}
                />
                {backgroundImage && (
                  <Button
                    className="rbea-rm-btn"
                    onClick={this.onRemoveImage}
                    isLink
                    isDestructive
                  >
                    {__("Remove Image", "easy-gtblocks")}
                  </Button>
                )}
              </BaseControl>
              <RangeControl
                label={__("Opacity", "easy-gtblocks")}
                value={imageopacity}
                onChange={(value) =>
                  setAttributes({
                    imageopacity: value !== undefined ? value : 20,
                  })
                }
                min={0}
                max={100}
                allowReset
              />
              <PanelBody
                title={__(
                  "Background Image Settings",
                  "easy-gtblocks"
                )}
                initialOpen={false}
              >
                <SelectControl
                  label={__("Image Position", "easy-gtblocks")}
                  value={bgimagePosition}
                  onChange={(value) =>
                    setAttributes({ bgimagePosition: value })
                  }
                  options={[
                    {
                      value: "top left",
                      label: __("Top Left", "easy-gtblocks"),
                    },
                    {
                      value: "top center",
                      label: __("Top Center", "easy-gtblocks"),
                    },
                    {
                      value: "top right",
                      label: __("Top Right", "easy-gtblocks"),
                    },
                    {
                      value: "center left",
                      label: __(
                        "Center Left",
                        "easy-gtblocks"
                      ),
                    },
                    {
                      value: "center top",
                      label: __("Center Top", "easy-gtblocks"),
                    },
                    {
                      value: "center right",
                      label: __(
                        "Center Right",
                        "easy-gtblocks"
                      ),
                    },
                    {
                      value: "bottom left",
                      label: __(
                        "Bottom Left",
                        "easy-gtblocks"
                      ),
                    },
                    {
                      value: "bottom center",
                      label: __(
                        "Bottom Center",
                        "easy-gtblocks"
                      ),
                    },
                    {
                      value: "bottom right",
                      label: __(
                        "Bottom Right",
                        "easy-gtblocks"
                      ),
                    },
                  ]}
                />
                <SelectControl
                  label={__("Image Repeat", "easy-gtblocks")}
                  value={bgimageRepeat}
                  onChange={(value) => setAttributes({ bgimageRepeat: value })}
                  options={[
                    {
                      value: "no-repeat",
                      label: __("No Repeat", "easy-gtblocks"),
                    },
                    {
                      value: "repeat",
                      label: __("Repeat", "easy-gtblocks"),
                    },
                    {
                      value: "repeat-x",
                      label: __("Repeat-X", "easy-gtblocks"),
                    },
                    {
                      value: "repeat-y",
                      label: __("Repeat-Y", "easy-gtblocks"),
                    },
                  ]}
                />
                <SelectControl
                  label={__("Image Size", "easy-gtblocks")}
                  value={bgthumbsize}
                  onChange={(value) => setAttributes({ bgthumbsize: value })}
                  options={[
                    {
                      value: "cover",
                      label: __("Cover", "easy-gtblocks"),
                    },
                    {
                      value: "auto",
                      label: __("Auto", "easy-gtblocks"),
                    },
                    {
                      value: "contain",
                      label: __("Contain", "easy-gtblocks"),
                    },
                  ]}
                />
              </PanelBody>
            </Fragment>
          )}
        </PanelBody>

        <PanelBody
          title={__("Typography", "easy-gtblocks")}
          initialOpen={false}
        >
          <PanelBody
            title={__("Title Typography", "easy-gtblocks")}
            initialOpen={false}
          >
            <SelectControl
              label={__("Font Family", "easy-gtblocks")}
              options={fontOptions}
              value={headingFontFamily}
              onChange={(value) => {
                setAttributes({
                  headingFontFamily: value,
                }),
                  loadGoogleFont(value);
              }}
            />
            <RangeControl
              label={__("Font Size", "easy-gtblocks")}
              value={headingFontSize}
              onChange={(value) =>
                this.props.setAttributes({
                  headingFontSize: value !== undefined ? value : 20,
                })
              }
              min={1}
              max={100}
              step={1}
              allowReset
            />
            <SelectControl
              label={__("Font Weight", "easy-gtblocks")}
              options={fontWeightOptions}
              value={headingFontWeight}
              onChange={(value) =>
                this.props.setAttributes({
                  headingFontWeight: value,
                })
              }
            />
            <RangeControl
              label={__("Line Height", "easy-gtblocks")}
              value={headingLineHeight}
              onChange={(value) =>
                this.props.setAttributes({
                  headingLineHeight: value !== undefined ? value : 1,
                })
              }
              min={0}
              max={100}
              step={1}
              allowReset
            />
          </PanelBody>
          <PanelBody
            title={__("Subtitle Typography", "easy-gtblocks")}
            initialOpen={false}
          >
            <SelectControl
              label={__("Font Family", "easy-gtblocks")}
              options={fontOptions}
              value={subFontFamily}
              onChange={(value) => {
                setAttributes({
                  subFontFamily: value,
                }),
                  loadGoogleFont(value);
              }}
            />
            <RangeControl
              label={__("Font Size", "easy-gtblocks")}
              value={subFontSize}
              onChange={(value) =>
                this.props.setAttributes({
                  subFontSize: value !== undefined ? value : 16,
                })
              }
              min={1}
              max={100}
              step={1}
              allowReset
            />
            <SelectControl
              label={__("Font Weight", "easy-gtblocks")}
              options={fontWeightOptions}
              value={subFontWeight}
              onChange={(value) =>
                this.props.setAttributes({
                  subFontWeight: value,
                })
              }
            />
            <RangeControl
              label={__("Line Height", "easy-gtblocks")}
              value={subLineHeight}
              onChange={(value) =>
                this.props.setAttributes({
                  subLineHeight: value !== undefined ? value : 1,
                })
              }
              min={0}
              max={100}
              step={1}
              allowReset
            />
          </PanelBody>
          <PanelBody
            title={__("Content Typography", "easy-gtblocks")}
            initialOpen={false}
          >
            <SelectControl
              label={__("Font Family", "easy-gtblocks")}
              options={fontOptions}
              value={contentFontFamily}
              onChange={(value) => {
                setAttributes({
                  contentFontFamily: value,
                }),
                  loadGoogleFont(value);
              }}
            />
            <RangeControl
              label={__("Font Size", "easy-gtblocks")}
              value={contentFontSize}
              onChange={(value) =>
                this.props.setAttributes({
                  contentFontSize: value !== undefined ? value : 16,
                })
              }
              min={1}
              max={100}
              step={1}
              allowReset
            />
            <SelectControl
              label={__("Font Weight", "easy-gtblocks")}
              options={fontWeightOptions}
              value={contentFontWeight}
              onChange={(value) =>
                this.props.setAttributes({
                  contentFontWeight: value,
                })
              }
            />
            <RangeControl
              label={__("Line Height", "easy-gtblocks")}
              value={contentLineHeight}
              onChange={(value) =>
                this.props.setAttributes({
                  contentLineHeight: value !== undefined ? value : 2,
                })
              }
              min={0}
              max={100}
              step={1}
              allowReset
            />
          </PanelBody>
        </PanelBody>

        <PanelBody
          title={__("Button Settings", "easy-gtblocks")}
          initialOpen={false}
        >
          <ToggleControl
            label={__("Open link in new tab")}
            checked={buttonTarget}
            onChange={() => {
              setAttributes({ buttonTarget: !buttonTarget });
            }}
          />
          <SelectControl
            label={__("Button Size", "easy-gtblocks")}
            value={buttonSize}
            options={buttonSizeOptions.map(({ value, label }) => ({
              value,
              label,
            }))}
            onChange={(value) => {
              this.props.setAttributes({
                buttonSize: value,
              });
            }}
          />
          <PanelBody
            title={__("Border", "easy-gtblocks")}
            initialOpen={false}
          >
            <SelectControl
              label={__("Style", "easy-gtblocks")}
              value={butborderStyle}
              options={[
                { value: "none", label: __("None") },
                { value: "solid", label: __("Solid") },
                { value: "dotted", label: __("Dotted") },
                { value: "dashed", label: __("Dashed") },
                { value: "double", label: __("Double") },
              ]}
              onChange={(value) => {
                setAttributes({ butborderStyle: value });
              }}
            />
            {borderStyle != "none" && (
              <RangeControl
                label={__("Thickness", "easy-gtblocks")}
                value={butborderWidth}
                onChange={(value) => {
                  setAttributes({ butborderWidth: value });
                }}
                min={0}
                max={20}
              />
            )}
            <RangeControl
              label={__("Rounded Corners", "easy-gtblocks")}
              value={butborderRadius}
              onChange={(value) => {
                setAttributes({ butborderRadius: value });
              }}
              min={0}
              max={50}
            />
            <RangeControl
              label={__("Vertical Padding", "easy-gtblocks")}
              value={vPadding}
              onChange={(value) => {
                setAttributes({ vPadding: value });
              }}
              min={0}
              max={200}
            />
            <RangeControl
              label={__("Horizontal Padding", "easy-gtblocks")}
              value={hPadding}
              onChange={(value) => {
                setAttributes({ hPadding: value });
              }}
              min={0}
              max={200}
            />
            <RangeControl
              label={__("Vertical Margin", "easy-gtblocks")}
              value={vMargin}
              onChange={(value) => {
                setAttributes({ vMargin: value });
              }}
              min={0}
              max={200}
            />
            <RangeControl
              label={__("Horizontal Margin", "easy-gtblocks")}
              value={hMargin}
              onChange={(value) => {
                setAttributes({ hMargin: value });
              }}
              min={0}
              max={200}
            />
          </PanelBody>
        </PanelBody>
        <PanelBody
          title={__("Button Color Settings", "easy-gtblocks")}
          initialOpen={false}
        >
          <Fragment>
            <PanelBody
              title={__("Background", "easy-gtblocks")}
              initialOpen={false}
            >
              <SelectControl
                label={__("Background Type", "easy-gtblocks")}
                value={buttonbackgroundType}
                onChange={(value) =>
                  setAttributes({ buttonbackgroundType: value })
                }
                options={buttonbackgroundTypeOptions}
              />
              {"color" == buttonbackgroundType && (
                <Fragment>
                  <p className="easy-gtblocks-setting-label">
                    {__("Background Color", "easy-gtblocks")}
                    <span className="components-base-control__label">
                      <span
                        className="component-color-indicator"
                        style={{ backgroundColor: buttonColor }}
                      ></span>
                    </span>
                  </p>
                  <ColorPalette
                    value={buttonColor}
                    onChange={(colorValue) =>
                      setAttributes({ buttonColor: colorValue })
                    }
                    allowReset
                  />
                  <p className="easy-gtblocks-setting-label">
                    {__(
                      "Background Hover Color",
                      "easy-gtblocks"
                    )}
                    <span className="components-base-control__label">
                      <span
                        className="component-color-indicator"
                        style={{ backgroundColor: buttonhColor }}
                      ></span>
                    </span>
                  </p>
                  <ColorPalette
                    value={buttonhColor}
                    onChange={(colorValue) =>
                      setAttributes({ buttonhColor: colorValue })
                    }
                    allowReset
                  />
                  <RangeControl
                    label={__("Opacity", "easy-gtblocks")}
                    value={butopacity}
                    onChange={(value) =>
                      setAttributes({
                        butopacity: value !== undefined ? value : 100,
                      })
                    }
                    min={0}
                    max={100}
                    allowReset
                  />
                </Fragment>
              )}
              {"gradient" == buttonbackgroundType && (
                <Fragment>
                  <p className="responsive-setting-label">
                    {__("Color 1", "easy-gtblocks")}
                    <span className="components-base-control__label">
                      <span
                        className="component-color-indicator"
                        style={{ backgroundColor: buttonbackgroundColor1 }}
                      ></span>
                    </span>
                  </p>
                  <ColorPalette
                    value={buttonbackgroundColor1}
                    onChange={(colorValue) =>
                      setAttributes({ buttonbackgroundColor1: colorValue })
                    }
                    allowReset
                  />

                  <p className="responsive-setting-label">
                    {__("Color 2", "easy-gtblocks")}
                    <span className="components-base-control__label">
                      <span
                        className="component-color-indicator"
                        style={{ backgroundColor: buttonbackgroundColor2 }}
                      ></span>
                    </span>
                  </p>
                  <ColorPalette
                    value={buttonbackgroundColor2}
                    onChange={(colorValue) =>
                      setAttributes({ buttonbackgroundColor2: colorValue })
                    }
                    allowReset
                  />
                  <RangeControl
                    label={__(
                      "Color Location 1",
                      "easy-gtblocks"
                    )}
                    value={buttoncolorLocation1}
                    min={0}
                    max={100}
                    onChange={(value) =>
                      setAttributes({ buttoncolorLocation1: value })
                    }
                  />
                  <RangeControl
                    label={__(
                      "Color Location 2",
                      "easy-gtblocks"
                    )}
                    value={buttoncolorLocation2}
                    min={0}
                    max={100}
                    onChange={(value) =>
                      setAttributes({ buttoncolorLocation2: value })
                    }
                  />
                  <RangeControl
                    label={__(
                      "Gradient Direction",
                      "easy-gtblocks"
                    )}
                    value={buttongradientDirection}
                    min={0}
                    max={100}
                    onChange={(value) =>
                      setAttributes({ buttongradientDirection: value })
                    }
                  />
                </Fragment>
              )}
            </PanelBody>
          </Fragment>
          <Fragment>
            <PanelBody
              title={__("Text", "easy-gtblocks")}
              initialOpen={false}
            >
              <p className="easy-gtblocks-setting-label">
                {__("Text Color", "easy-gtblocks")}
                <span className="components-base-control__label">
                  <span
                    className="component-color-indicator"
                    style={{ backgroundColor: buttonColor }}
                  ></span>
                </span>
              </p>
              <ColorPalette
                value={buttonTextColor}
                onChange={(colorValue) =>
                  setAttributes({ buttonTextColor: colorValue })
                }
                allowReset
              />
              <p className="easy-gtblocks-setting-label">
                {__("Text HoverColor", "easy-gtblocks")}
                <span className="components-base-control__label">
                  <span
                    className="component-color-indicator"
                    style={{ backgroundColor: buttonhTextColor }}
                  ></span>
                </span>
              </p>
              <ColorPalette
                value={buttonhTextColor}
                onChange={(colorValue) =>
                  setAttributes({ buttonhTextColor: colorValue })
                }
                allowReset
              />
            </PanelBody>
          </Fragment>
        </PanelBody>

        <PanelBody title={__("Icon Settings")} initialOpen={false}>
          <Fragment>
            <p className="components-base-control__label">{__("Icon")}</p>
            <FontIconPicker
              icons={svg_icons}
              renderFunc={renderSVG}
              theme="default"
              value={icon}
              onChange={(value) => setAttributes({ icon: value })}
              isMulti={false}
              noSelectedPlaceholder={__("Select Icon")}
            />
            <SelectControl
              label={__("Icon Position")}
              value={iconPosition}
              onChange={(value) => setAttributes({ iconPosition: value })}
              options={[
                { value: "before", label: __("Before Text") },
                { value: "after", label: __("After Text") },
              ]}
            />
            <p className="easy-gtblocks-setting-label">
              {__("Icon Color", "easy-gtblocks")}
              <span className="components-base-control__label">
                <span
                  className="component-color-indicator"
                  style={{ backgroundColor: icon_color }}
                ></span>
              </span>
            </p>
            <ColorPalette
              value={icon_color}
              onChange={(value) => setAttributes({ icon_color: value })}
              allowReset
            />
            <p className="easy-gtblocks-setting-label">
              {__("Icon Hover Color", "easy-gtblocks")}
              <span className="components-base-control__label">
                <span
                  className="component-color-indicator"
                  style={{ backgroundColor: icon_hcolor }}
                ></span>
              </span>
            </p>
            <ColorPalette
              value={icon_hcolor}
              onChange={(value) => setAttributes({ icon_hcolor: value })}
              allowReset
            />
          </Fragment>
        </PanelBody>

        <PanelBody
          title={__("Spacing", "easy-gtblocks")}
          initialOpen={false}
        >
          <RangeControl
            label={__("Title Bottom Margin", "easy-gtblocks")}
            value={titleSpace}
            onChange={(value) =>
              setAttributes({ titleSpace: value !== undefined ? value : 8 })
            }
            min={-100}
            max={100}
            allowReset
          />
          <RangeControl
            label={__(
              "Subtitle Bottom Margin",
              "easy-gtblocks"
            )}
            value={subtitleSpace}
            onChange={(value) =>
              setAttributes({ subtitleSpace: value !== undefined ? value : 16 })
            }
            min={-100}
            max={100}
            allowReset
          />
          <RangeControl
            label={__("Content Top Margin", "easy-gtblocks")}
            value={contenttopSpace}
            onChange={(value) =>
              setAttributes({
                contenttopSpace: value !== undefined ? value : 16,
              })
            }
            min={-100}
            max={100}
            allowReset
          />
          <RangeControl
            label={__(
              "Content Bottom Margin",
              "easy-gtblocks"
            )}
            value={contentSpace}
            onChange={(value) =>
              setAttributes({ contentSpace: value !== undefined ? value : 16 })
            }
            min={-100}
            max={100}
            allowReset
          />
          <RangeControl
            label={__("Block Top Margin", "easy-gtblocks")}
            value={blockmargin}
            onChange={(value) =>
              setAttributes({ blockmargin: value !== undefined ? value : 2 })
            }
            min={-100}
            max={200}
            allowReset
          />
          <RangeControl
            label={__("Block Bottom Margin", "easy-gtblocks")}
            value={blockbotmargin}
            onChange={(value) =>
              setAttributes({ blockbotmargin: value !== undefined ? value : 2 })
            }
            min={-100}
            max={200}
            allowReset
          />
          <RangeControl
            label={__("Block Left Margin", "easy-gtblocks")}
            value={blockleftmargin}
            onChange={(value) =>
              setAttributes({
                blockleftmargin: value !== undefined ? value : 0,
              })
            }
            min={-100}
            max={200}
            allowReset
          />
          <RangeControl
            label={__("Block Right Margin", "easy-gtblocks")}
            value={blockrightmargin}
            onChange={(value) =>
              setAttributes({
                blockrightmargin: value !== undefined ? value : 0,
              })
            }
            min={-100}
            max={200}
            allowReset
          />
        </PanelBody>

        <PanelBody
          title={__("Border Settings", "easy-gtblocks")}
          initialOpen={false}
        >
          <SelectControl
            label={__("Border Style", "easy-gtblocks")}
            value={borderStyle}
            onChange={(value) => setAttributes({ borderStyle: value })}
            options={[
              {
                value: "none",
                label: __("None", "easy-gtblocks"),
              },
              {
                value: "solid",
                label: __("Solid", "easy-gtblocks"),
              },
              {
                value: "dotted",
                label: __("Dotted", "easy-gtblocks"),
              },
              {
                value: "dashed",
                label: __("Dashed", "easy-gtblocks"),
              },
              {
                value: "double",
                label: __("Double", "easy-gtblocks"),
              },
              {
                value: "groove",
                label: __("Groove", "easy-gtblocks"),
              },
              {
                value: "inset",
                label: __("Inset", "easy-gtblocks"),
              },
              {
                value: "outset",
                label: __("Outset", "easy-gtblocks"),
              },
              {
                value: "ridge",
                label: __("Ridge", "easy-gtblocks"),
              },
            ]}
          />
          {"none" != borderStyle && (
            <Fragment>
              <RangeControl
                label={__("Border Width", "easy-gtblocks")}
                value={borderWidth}
                onChange={(value) =>
                  setAttributes({
                    borderWidth: value !== undefined ? value : 0,
                  })
                }
                min={0}
                max={50}
                allowReset
              />
              <Fragment>
                <p>
                  {__("Border Color", "easy-gtblocks")}
                  <span className="components-base-control__label">
                    <span
                      className="component-color-indicator"
                      style={{ backgroundColor: borderColor }}
                    ></span>
                  </span>
                </p>
                <ColorPalette
                  value={borderColor}
                  onChange={(colorValue) =>
                    setAttributes({ borderColor: colorValue })
                  }
                  allowReset
                />
              </Fragment>
            </Fragment>
          )}
          <RangeControl
            label={__("Border Radius", "easy-gtblocks")}
            value={borderRadius}
            onChange={(value) =>
              setAttributes({ borderRadius: value !== undefined ? value : 12 })
            }
            min={0}
            max={50}
            allowReset
          />
          <BoxShadowControl
            setAttributes={setAttributes}
            label={__("Box Shadow", "easy-gtblocks")}
            boxShadowColor={{ value: boxShadowColor, label: __("Color") }}
            boxShadowHOffset={{
              value: boxShadowHOffset,
              label: __("Horizontal", "easy-gtblocks"),
            }}
            boxShadowVOffset={{
              value: boxShadowVOffset,
              label: __("Vertical", "easy-gtblocks"),
            }}
            boxShadowBlur={{
              value: boxShadowBlur,
              label: __("Blur", "easy-gtblocks"),
            }}
            boxShadowSpread={{
              value: boxShadowSpread,
              label: __("Spread", "easy-gtblocks"),
            }}
            boxShadowPosition={{
              value: boxShadowPosition,
              label: __("Position", "easy-gtblocks"),
            }}
          />
        </PanelBody>

        <PanelColorSettings
          title={__("Text Color Settings", "easy-gtblocks")}
          initialOpen={false}
          colorSettings={[
            {
              value: textColor,
              onChange: onChangeTextColor,
              label: __("Text Color", "easy-gtblocks"),
            },
          ]}
        ></PanelColorSettings>
      </InspectorControls>
    );
  }
}
