/**
 * BLOCK: Easy GT Blocks Space Divider
 */

// Import block dependencies and components
import classnames from "classnames";
import Edit from "./components/edit";
import Save from "./components/save";

// Components
const { __ } = wp.i18n;

// Register block
const { registerBlockType } = wp.blocks;

// Register the block
registerBlockType("easy-gtblocks/divider", {
  title: __("Divider", "easy-gtblocks"),
  description: __(
    "Add a divider and spacer between your blocks.",
    "easy-gtblocks"
  ),
  icon: "minus",
  category: "Easy_GTBlocks",
  keywords: [
    __("divider", "easy-gtblocks"),
    __("spacer", "easy-gtblocks"),
    __("responsive", "easy-gtblocks"),
  ],
  example: {},
  attributes: {
    spacerHeight: {
      type: "number",
      default: 30,
    },
    spacerDivider: {
      type: "boolean",
      default: false,
    },
    spacerDividerStyle: {
      type: "string",
      default: "solid",
    },
    spacerDividerColor: {
      type: "string",
      default: "#000000",
    },
    spacerDividerHeight: {
      type: "number",
      default: 7,
    },
    spacerDividerWidth: {
      type: "number",
      default: 60,
    },
    spacerDividerAlignment: {
      type: "string",
      default: "center",
    },
  },

  EASY_GTBLOCKS_settings_data: {
    EASY_GTBLOCKS_spacer_spacerHeight: {
      title: __("Vertical Margin", "easy-gtblocks"),
    },
    EASY_GTBLOCKS_spacer_spacerDivider: {
      title: __("Add Divider", "easy-gtblocks"),
    },
    EASY_GTBLOCKS_spacer_spacerDividerStyle: {
      title: __("Divider Style", "easy-gtblocks"),
    },
    EASY_GTBLOCKS_spacer_spacerDividerHeight: {
      title: __("Divider Height", "easy-gtblocks"),
    },
    EASY_GTBLOCKS_spacer_spacerDividerWidth: {
      title: __("Divider Width", "easy-gtblocks"),
    },
    EASY_GTBLOCKS_spacer_dividerColor: {
      title: __("Divider Color", "easy-gtblocks"),
    },
  },

  supports: { align: ["wide", "full", "center"] },

  /* Render the block in the editor. */
  edit: (props) => {
    return <Edit {...props} />;
  },

  /* Save the block markup. */
  save: (props) => {
    return <Save {...props} />;
  },
});
