/**
 * BLOCK: Easy GT Blocks Googlemap
 */

// Import block dependencies and components
import Edit from "./components/edit";
import Save from "./components/save";

// Import CSS
import "./styles/style.scss";
import "./styles/styles.editor.scss";

// Internationalization
const { __ } = wp.i18n;

// Register block
const { registerBlockType } = wp.blocks;

// Register the block
registerBlockType("easy-gtblocks/googlemap", {
  title: __("Google Map", "easy-gtblocks"),
  description: __(
    "Add an address or location to drop a pin on a Google map.",
    "easy-gtblocks"
  ),
  icon: "location",
  category: "Easy_GTBlocks",
  keywords: [
    __("address", "easy-gtblocks"),
    __("map", "easy-gtblocks"),
    __("google", "easy-gtblocks"),
    __("directions", "easy-gtblocks"),
    __("responsive", "easy-gtblocks"),
  ],
  example: {},
  attributes: {
    address: {
      type: "string",
    },
    apiKey: {
      type: "string",
    },
    zoom: {
      type: "number",
      default: 12,
    },
    height: {
      type: "number",
      default: 400,
    },
    pinned: {
      type: "boolean",
      default: false,
    },
  },
  EASY_GTBLOCKS_settings_data: {
    EASY_GTBLOCKS_map_zoom: {
      title: __("Zoom", "easy-gtblocks"),
    },
    EASY_GTBLOCKS_map_height: {
      title: __("Height in pixels", "easy-gtblocks"),
    },
  },

  /* Render the block in the editor. */
  edit: (props) => {
    return <Edit {...props} />;
  },

  /* Save the block markup. */
  save: (props) => {
    return <Save {...props} />;
  },
});
