/**
 * BLOCK: Easy GT Blocks Icon List
 */

// Import block dependencies and components
import Edit from "./components/edit";
import Save from "./components/save";

// Import CSS
import "./styles/style.scss";
import "./styles/styles.editor.scss";

// Internationalization
const { __ } = wp.i18n;

const ITEM_COUNT = 1;

const icons = [];

for (var i = 1; i <= 2; i++) {
  icons.push({
    label: "#Label",
    image_icon: "icon",
    icon: "fab fa-arrow-circle-right",
    image: "",
    icon_color: "#3a3a3a",
    label_color: "",
    icon_hover_color: "",
    label_hover_color: "",
    icon_bg_color: "",
    icon_bg_hover_color: "",
    icon_border_color: "",
    icon_border_hover_color: "",
    link: "#",
    target: false,
    disableLink: true,
    hideLabel: false,
  });
}

// Register block
const { registerBlockType } = wp.blocks;

// Register the block
registerBlockType("easy-gtblocks/icons-list", {
  title: __("Icons List", "easy-gtblocks"),
  description: __("Add a list of icons", "easy-gtblocks"),
  icon: "list-view",
  category: "Easy_GTBlocks",
  keywords: [
    __("icons", "easy-gtblocks"),
    __("list", "easy-gtblocks"),
    __("responsive", "easy-gtblocks"),
  ],
  example: {},
  attributes: {
    align: {
      type: "string",
      default: "left",
    },
    icon_count: {
      type: "number",
      default: ITEM_COUNT,
    },
    icons: {
      type: "array",
      default: icons,
    },
    gap: {
      type: "number",
      default: 10,
    },
    inner_gap: {
      type: "number",
      default: 15,
    },
    iconPosition: {
      type: "string",
      default: "middle",
    },
    size: {
      type: "number",
      default: 16,
    },
    bgSize: {
      type: "number",
      default: 0,
    },
    border: {
      type: "number",
      default: 0,
    },
    borderRadius: {
      type: "number",
      default: 0,
    },
    hideLabel: {
      type: "boolean",
      default: false,
    },
    labelFontFamily: {
      type: "string",
    },
    labelFontWeight: {
      type: "string",
    },
    labelFontSize: {
      type: "number",
    },
    labelFontSizeTablet: {
      type: "number",
    },
    labelFontSizeMobile: {
      type: "number",
    },
    labelFontLineHeight: {
      type: "number",
      default: 1,
    },
    icon_layout: {
      type: "string",
      default: "vertical",
    },
    fontSizeType: {
      type: "string",
      default: "px",
    },
    maincounterId: {
      type: "string",
      default: 1,
    },
  },
  EASY_GTBLOCKS_settings_data: {
    EASY_GTBLOCKS_icon_icon_layout: {
      title: __("Layout", "easy-gtblocks"),
    },
    EASY_GTBLOCKS_icon_iconPosition: {
      title: __("Icon Alignment", "easy-gtblocks"),
    },
    EASY_GTBLOCKS_icon_size: {
      title: __("Icon Size", "easy-gtblocks"),
    },
    EASY_GTBLOCKS_icon_gap: {
      title: __("Gap between Items", "easy-gtblocks"),
    },
    EASY_GTBLOCKS_icon_inner_gap: {
      title: __("Gap between Icon and Label", "easy-gtblocks"),
    },
  },
  /* Render the block in the editor. */
  edit: (props) => {
    return <Edit {...props} />;
  },

  /* Save the block markup. */
  save: (props) => {
    return <Save {...props} />;
  },
});
