/**
 * Internal dependencies
 */
import SliderPanel from "../../../utils/components/slider-panel";
import ResponsiveTabsControl from "../../../utils/components/responsive-tabs-control";
import SizeControl from "../../../utils/components/size-control";

/**
 * WordPress dependencies
 */
import { __ } from "@wordpress/i18n";
import { Component, Fragment } from "@wordpress/element";
import {
  InspectorControls,
  InspectorAdvancedControls,
  PanelColorSettings,
} from "@wordpress/block-editor";
import {
  PanelBody,
  RangeControl,
  ToggleControl,
  BaseControl,
  SelectControl,
} from "@wordpress/components";

/**
 * Inspector controls
 */
class Inspector extends Component {
  constructor() {
    super(...arguments);
    this.setSizeControl = this.setSizeControl.bind(this);
    this.setRadiusTo = this.setRadiusTo.bind(this);
    this.setHeightTo = this.setHeightTo.bind(this);
    this.state = {
      temporaryInput: null,
    };
  }

  setRadiusTo(value) {
    this.props.setAttributes({ radius: value });
  }

  setSizeControl(value) {
    this.props.setAttributes({ gridSize: value });
  }

  setHeightTo(value) {
    this.props.setAttributes({ height: value });
  }

  setTemporayInput(value) {
    this.setState({ temporaryInput: value });
  }

    getSmallImageNavigationHelp(checked) {
    return checked
      ? __("Turn this OFF if you are using larger images.", "easy-gtblocks")
      : __("Turn this ON if you are using smaller images.", "easy-gtblocks");
  }
getThumbnailNavigationHelp(checked) {
    return checked
      ? __("Showing thumbnail navigation.", "easy-gtblocks")
      : __("Toggle to show thumbnails.", "easy-gtblocks");
  }

  getResponsiveHeightHelp(checked) {
    return checked
      ? __(
          "Percentage based height is activated.",
          "easy-gtblocks"
        )
      : __(
          "Toggle for percentage based height.",
          "easy-gtblocks"
        );
  }

  getLightboxHelp(checked) {
    return checked
      ? __("Image lightbox is enabled.", "easy-gtblocks")
      : __(
          "Toggle to enable the image lightbox.",
          "easy-gtblocks"
        );
  }

  render() {
    const { attributes, isSelected, setAttributes } = this.props;

    const {
      align,
      gridSize,
      gutter,
      height,
      radius,
      thumbnails,
        isSmallImage,
      responsiveHeight,
      lightbox,
      borderWidth,
      borderColor,
      borderStyle,
      iconBackgroundColor,
      iconColor,
      iconBackgroundRadius,
      iconBackgroundOpacity,
      width,
      customWidth,
    } = attributes;

    const { temporaryInput } = this.state;

    return (
      isSelected && (
        <Fragment>
          <InspectorControls>
            <PanelBody
              title={__("Image Carousel", "easy-gtblocks")}
              initialOpen={false}
            >
              <SizeControl
                {...this.props}
                type={"grid"}
                label={__("Size")}
                onChange={this.setSizeControl}
                value={gridSize}
                resetValue={"xlrg"}
              />
              {gridSize !== null && (align === "wide" || align === "full") && (
                <ResponsiveTabsControl
                  {...this.props}
                  label={__("Gutter", "easy-gtblocks")}
                  max={20}
                />
              )}
              {gridSize !== "xlrg" && !align && (
                <ResponsiveTabsControl
                  {...this.props}
                  label={__("Gutter", "easy-gtblocks")}
                  max={50}
                />
              )}
              {gutter > 0 && (
                <RangeControl
                  label={__("Radius", "easy-gtblocks")}
                  value={radius}
                  onChange={this.setRadiusTo}
                  min={0}
                  max={50}
                  step={1}
                />
              )}
              <ToggleControl
                label={__("Custom Width", "easy-gtblocks")}
                checked={!!customWidth}
                onChange={() => setAttributes({ customWidth: !customWidth })}
              />
              {!!customWidth && (
                <RangeControl
                  label={__(
                    "Width in pixels",
                    "easy-gtblocks"
                  )}
                  value={width}
                  onChange={(value) =>
                    setAttributes({
                      width: value,
                    })
                  }
                  min={0}
                  max={1000}
                  step={1}
                />
              )}
              {!responsiveHeight && (
                <BaseControl
                  label={__(
                    "Height in pixels",
                    "easy-gtblocks"
                  )}
                  className={"block-height-control"}
                >
                  <input
                    type="number"
                    className={"block-height-control__input"}
                    onChange={(event) => {
                      const unprocessedValue = event.target.value;
                      const inputValue =
                        unprocessedValue !== ""
                          ? parseInt(event.target.value, 10)
                          : undefined;
                      if (inputValue < 0 && inputValue !== undefined) {
                        this.setTemporayInput(inputValue);
                        this.setHeightTo(0);
                        return;
                      }
                      this.setTemporayInput(null);
                      this.setHeightTo(inputValue);
                    }}
                    value={temporaryInput || height}
                    min={0}
                    step="10"
                  />
                </BaseControl>
              )}
              <ToggleControl
                label={__("Small Images", "easy-gtblocks")}
                checked={!!isSmallImage}
                onChange={() => setAttributes({ isSmallImage: !isSmallImage })}
                help={this.getSmallImageNavigationHelp}
              />
              <ToggleControl
                label={__("Thumbnails", "easy-gtblocks")}
                checked={!!thumbnails}
                onChange={() => setAttributes({ thumbnails: !thumbnails })}
                help={this.getThumbnailNavigationHelp}
              />
              <ToggleControl
                label={__("Lightbox", "easy-gtblocks")}
                checked={!!lightbox}
                onChange={() => setAttributes({ lightbox: !lightbox })}
                help={this.getLightboxHelp}
              />
            </PanelBody>
            <PanelColorSettings
              title={__("Arrow", "easy-gtblocks")}
              initialOpen={false}
              colorSettings={[
                {
                  value: iconColor,
                  onChange: (newIconColor) =>
                    setAttributes({ iconColor: newIconColor }),
                  label: __("Color", "easy-gtblocks"),
                },
                {
                  value: iconBackgroundColor,
                  onChange: (newiconBackgroundColor) =>
                    setAttributes({
                      iconBackgroundColor: newiconBackgroundColor,
                    }),
                  label: __(
                    "Background Color",
                    "easy-gtblocks"
                  ),
                },
              ]}
            >
              <RangeControl
                label={__(
                  "Background Opacity",
                  "easy-gtblocks"
                )}
                value={iconBackgroundOpacity}
                onChange={(newiconBackgroundOpacity) =>
                  setAttributes({
                    iconBackgroundOpacity: newiconBackgroundOpacity,
                  })
                }
                min={0}
                max={100}
                step={1}
              />
              <RangeControl
                label={__(
                  "Background Radius",
                  "easy-gtblocks"
                )}
                value={iconBackgroundRadius}
                onChange={(newiconBackgroundradius) =>
                  setAttributes({
                    iconBackgroundRadius: newiconBackgroundradius,
                  })
                }
                min={0}
                max={50}
                step={1}
              />
            </PanelColorSettings>
            <PanelColorSettings
              title={__("Border", "easy-gtblocks")}
              initialOpen={false}
              colorSettings={[
                {
                  value: borderColor,
                  onChange: (newBorderColor) =>
                    setAttributes({ borderColor: newBorderColor }),
                  label: __("Border Color", "easy-gtblocks"),
                },
              ]}
            >
              <SelectControl
                label={__("Border Style", "easy-gtblocks")}
                value={borderStyle}
                options={[
                  {
                    value: "none",
                    /* translators: abbreviation for medium size */
                    label: __("None", "easy-gtblocks"),
                    tooltip: __("None", "easy-gtblocks"),
                  },
                  {
                    value: "solid",
                    label: __("Solid", "easy-gtblocks"),
                    shortName: __("Solid", "easy-gtblocks"),
                  },
                  {
                    value: "dotted",
                    /* translators: abbreviation for small size */
                    label: __("Dotted", "easy-gtblocks"),
                    tooltip: __("Dotted", "easy-gtblocks"),
                  },
                  {
                    value: "dashed",
                    /* translators: abbreviation for medium size */
                    label: __("Dashed", "easy-gtblocks"),
                    tooltip: __("Dashed", "easy-gtblocks"),
                  },
                ]}
                onChange={(newborderStyle) =>
                  setAttributes({ borderStyle: newborderStyle })
                }
              />
              <RangeControl
                label={__("Border Size", "easy-gtblocks")}
                value={borderWidth}
                onChange={(newBorderWidth) =>
                  setAttributes({ borderWidth: newBorderWidth })
                }
                min={0}
                max={20}
                step={1}
              />
            </PanelColorSettings>
            <SliderPanel {...this.props} />
          </InspectorControls>
          <InspectorAdvancedControls>
            <ToggleControl
              label={__("Responsive height", "easy-gtblocks")}
              checked={!!responsiveHeight}
              onChange={() =>
                setAttributes({ responsiveHeight: !responsiveHeight })
              }
              help={this.getResponsiveHeightHelp}
            />
          </InspectorAdvancedControls>
        </Fragment>
      )
    );
  }
}

export default Inspector;
