/**
 * BLOCK: Easy GT Blocks Post and Page Grid
 */

// Import block dependencies and components
import edit from "./components/edit";

// Import CSS
import "./styles/style.scss";
import "./styles/styles.editor.scss";

// Components
const { __ } = wp.i18n;

// Register block controls
const { registerBlockType } = wp.blocks;

// Register alignments
const validAlignments = ["center", "wide", "full"];

// Register the block
registerBlockType(
  "easy-gtblocks/easy-gtblocks-post-grid",
  {
    title: __(
      "Post and Page Grid",
      "easy-gtblocks"
    ),
    description: __(
      "Add a grid or list of customizable posts or pages.",
      "easy-gtblocks"
    ),
    icon: "grid-view",
    category: "Easy_GTBlocks",
    keywords: [
      __("post", "easy-gtblocks"),
      __("page", "easy-gtblocks"),
      __("grid", "easy-gtblocks"),
    ],
    example: {},

    getEditWrapperProps(attributes) {
      const { align } = attributes;
      if (-1 !== validAlignments.indexOf(align)) {
        return { "data-align": align };
      }
    },

    edit,

    EASY_GTBLOCKS_settings_data: {
      EASY_GTBLOCKS_postgrid_postType: {
        title: __("Content Type", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_queryControls: {
        title: __("Query Controls", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_offset: {
        title: __("Post Offset", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_columns: {
        title: __("Columns", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_displaySectionTitle: {
        title: __("Display Section Title", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_sectionTitle: {
        title: __("Section Title", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_displayPostImage: {
        title: __("Display Featured Image", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_imageSizeValue: {
        title: __("Image Size", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_displayPostTitle: {
        title: __("Display Post Title", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_displayPostAuthor: {
        title: __("Display Post Author", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_displayPostDate: {
        title: __("Display Post Date", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_displayPostExcerpt: {
        title: __("Display Post Excerpt", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_excerptLength: {
        title: __("Excerpt Length", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_displayPostLink: {
        title: __(
          "Display Continue Reading Link",
          "easy-gtblocks"
        ),
      },
      EASY_GTBLOCKS_postgrid_readMoreText: {
        title: __("Read More Text", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_sectionTag: {
        title: __("Post Grid Section Tag", "easy-gtblocks"),
      },
      EASY_GTBLOCKS_postgrid_sectionTitleTag: {
        title: __(
          "Section Title Heading Tag",
          "easy-gtblocks"
        ),
      },
      EASY_GTBLOCKS_postgrid_postTitleTag: {
        title: __("Post Title Heading Tag", "easy-gtblocks"),
      },
    },

    // Render via PHP
    save() {
      return null;
    },
  }
);
