/**
 * Inspector Controls
 */

import times from "lodash/times";

// Setup the block
const { __ } = wp.i18n;
const { Component, Fragment } = wp.element;

// Import block components
const { InspectorControls, PanelColorSettings, MediaUpload } = wp.editor;

// Import Inspector components
const {
  PanelBody,
  RangeControl,
  SelectControl,
  TextControl,
  BaseControl,
  Button,
  ToggleControl,
} = wp.components;
import BoxShadowControl from "../../../utils/components/box-shadow";
import fontOptions from "../../../utils/googlefonts";
import { loadGoogleFont } from "../../../utils/font";

/**
 * Create an Inspector Controls wrapper Component
 */
export default class Inspector extends Component {
  constructor(props) {
    super(...arguments);
    this.onRemoveImage = this.onRemoveImage.bind(this);
    this.onSelectImage = this.onSelectImage.bind(this);
  }

  /*
   * Event to set Image as null while removing.
   */
  onRemoveImage() {
    const { setAttributes } = this.props;

    setAttributes({ backgroundImage: null });
  }

  /*
   * Event to set Image as while adding.
   */
  onSelectImage(media) {
    const { setAttributes } = this.props;
    const { backgroundImage } = this.props.attributes;

    if (!media || !media.url) {
      setAttributes({ backgroundImage: null });
      return;
    }

    if (!media.type || "image" != media.type) {
      return;
    }

    setAttributes({ backgroundImage: media.url });
  }

  render() {
    // Font Weight Options
    const fontWeightOptions = [
      {
        value: "100",
        label: __("100", "easy-gtblocks"),
      },
      {
        value: "200",
        label: __("200", "easy-gtblocks"),
      },
      {
        value: "300",
        label: __("300", "easy-gtblocks"),
      },
      {
        value: "400",
        label: __("400", "easy-gtblocks"),
      },
      {
        value: "500",
        label: __("500", "easy-gtblocks"),
      },
      {
        value: "600",
        label: __("600", "easy-gtblocks"),
      },
      {
        value: "700",
        label: __("700", "easy-gtblocks"),
      },
      {
        value: "800",
        label: __("800", "easy-gtblocks"),
      },
      {
        value: "900",
        label: __("900", "easy-gtblocks"),
      },
    ];

    const gutterOptions = [
      {
        value: "no",
        label: __("None", "easy-gtblocks"),
        shortName: __("None", "easy-gtblocks"),
      },
      {
        value: "small",
        /* translators: abbreviation for small size */
        label: __("S", "easy-gtblocks"),
        tooltip: __("Small", "easy-gtblocks"),
      },
      {
        value: "medium",
        /* translators: abbreviation for medium size */
        label: __("M", "easy-gtblocks"),
        tooltip: __("Medium", "easy-gtblocks"),
      },
      {
        value: "large",
        /* translators: abbreviation for large size */
        label: __("L", "easy-gtblocks"),
        tooltip: __("Large", "easy-gtblocks"),
      },
      {
        value: "huge",
        /* translators: abbreviation for largest size */
        label: __("XL", "easy-gtblocks"),
        tooltip: __("Huge", "easy-gtblocks"),
      },
    ];
    const iconSizeOptions = [
      {
        value: "1.5em",
        label: __("Normal", "easy-gtblocks"),
        shortName: __("Normal", "easy-gtblocks"),
      },
      {
        value: "1em",
        /* translators: abbreviation for small size */
        label: __("Small", "easy-gtblocks"),
        tooltip: __("Small", "easy-gtblocks"),
      },
      {
        value: "2em",
        /* translators: abbreviation for medium size */
        label: __("Medium", "easy-gtblocks"),
        tooltip: __("Medium", "easy-gtblocks"),
      },
      {
        value: "3em",
        /* translators: abbreviation for large size */
        label: __("Large", "easy-gtblocks"),
        tooltip: __("Large", "easy-gtblocks"),
      },
      {
        value: "0.8em",
        /* translators: abbreviation for largest size */
        label: __("Tiny", "easy-gtblocks"),
        tooltip: __("Tiny", "easy-gtblocks"),
      },
    ];

    // Setup the attributes
    const {
      attributes: {
        count,
        gutter,
        teamBlock,
        imageSize,
        designationColor,
        descriptionColor,
        socialIconColor,
        titleFontSize,
        titleFontFamily,
        descriptionFontFamily,
        designationFontFamily,
        designationFontSize,
        descriptionFontSize,
        titleFontWeight,
        designationFontWeight,
        descriptionFontWeight,
        titleLineHeight,
        designationLineHeight,
        descriptionLineHeight,
        titleSpacing,
        designationSpacing,
        descriptionSpacing,
        socialIconSpacing,
        imageMarginTop,
        imageMarginBottom,
        titleColor,
        backgroundColor,
        borderColor,
        borderWidth,
        borderRadius,
        padding,
        imageShape,
        boxShadowColor,
        boxShadowHOffset,
        boxShadowVOffset,
        boxShadowBlur,
        boxShadowSpread,
        boxShadowPosition,
        opacity,
        secondaryBackgroundColor,
        gradientDegree,
        colorLocation1,
        colorLocation2,
        bgGradient,
        backgroundImage,
        backgroundPosition,
        backgroundRepeat,
        backgroundSize,
        backgroundAttachment,
        facebook,
        twitter,
        linkedin,
        instagram,
        email,
        youtube,
        pinterest,
        iconSize,
        imageWidth,
          showImage,
          showName,
          showDesignation,
          showDescription,
          showSocialIcons,
      },
      setAttributes,
    } = this.props;

    // Update color values
    const onChangeDesignationColor = (value) =>
      setAttributes({ designationColor: value });
    const onChangeDescriptionColor = (value) =>
      setAttributes({ descriptionColor: value });
    const onChangeSocialIconColor = (value) =>
      setAttributes({ socialIconColor: value });
    const onChangetitleColor = (value) => setAttributes({ titleColor: value });
    const onChangeBackgroundColor = (value) =>
      setAttributes({ backgroundColor: value });
    const onChangeBorderColor = (value) =>
      setAttributes({ borderColor: value });
    const onChangeSecondaryBackgroundColor = (value) =>
      setAttributes({ secondaryBackgroundColor: value });

    const imageShapeOptions = [
      {
        value: "default",
        label: __("Default", "easy-gtblocks"),
        shortName: __("Default", "easy-gtblocks"),
      },
      {
        value: "circle",
        label: __("Circle", "easy-gtblocks"),
        shortName: __("Circle", "easy-gtblocks"),
      },
      {
        value: "square",
        label: __("Square", "easy-gtblocks"),
        shortName: __("Square", "easy-gtblocks"),
      },
      {
        value: "blob",
        label: __("Blob", "easy-gtblocks"),
        shortName: __("Blob", "easy-gtblocks"),
      },
    ];

    return (
      <InspectorControls key="inspector">
        <PanelBody
          title={__("General", "easy-gtblocks")}
          initialOpen={false}
        >
          <RangeControl
            label={__(
              "Number of Team Member Boxes",
              "easy-gtblocks"
            )}
            value={count}
            onChange={(newCount) => {
              let cloneTest_block = [...teamBlock];
              if (cloneTest_block.length < newCount) {
                const incAmount = Math.abs(newCount - cloneTest_block.length);

                {
                  times(incAmount, (n) => {
                    cloneTest_block.push({
                      title: "Team Title " + newCount,
                      descriptions: "",
                    });
                  });
                }
                setAttributes({ teamBlock: cloneTest_block });
              } else {
                const incAmount = Math.abs(newCount - cloneTest_block.length);
                let data_new = cloneTest_block;
                for (var i = 0; i < incAmount; i++) {
                  data_new.pop();
                }
                setAttributes({ teamBlock: data_new });
              }
              setAttributes({ count: newCount });
            }}
            min={1}
            max={4}
            step={1}
          />
          {count > 1 && (
            <SelectControl
              label={__("Gutter", "easy-gtblocks")}
              value={gutter}
              options={gutterOptions}
              onChange={(newGutter) => setAttributes({ gutter: newGutter })}
            />
          )}
          <BoxShadowControl
            setAttributes={setAttributes}
            label={__("Box Shadow", "easy-gtblocks")}
            boxShadowColor={{ value: boxShadowColor, label: __("Color") }}
            boxShadowHOffset={{
              value: boxShadowHOffset,
              label: __("Horizontal", "easy-gtblocks"),
            }}
            boxShadowVOffset={{
              value: boxShadowVOffset,
              label: __("Vertical", "easy-gtblocks"),
            }}
            boxShadowBlur={{
              value: boxShadowBlur,
              label: __("Blur", "easy-gtblocks"),
            }}
            boxShadowSpread={{
              value: boxShadowSpread,
              label: __("Spread", "easy-gtblocks"),
            }}
            boxShadowPosition={{
              value: boxShadowPosition,
              label: __("Position", "easy-gtblocks"),
            }}
          />
          <RangeControl
            label={__("Border Width", "easy-gtblocks")}
            value={borderWidth}
            onChange={(value) =>
              this.props.setAttributes({
                borderWidth: value,
              })
            }
            min={0}
            max={50}
            step={1}
          />
          <RangeControl
            label={__("Border Radius", "easy-gtblocks")}
            value={borderRadius}
            onChange={(value) =>
              this.props.setAttributes({
                borderRadius: value,
              })
            }
            min={0}
            max={50}
            step={1}
          />
          <RangeControl
            label={__("Padding", "easy-gtblocks")}
            value={padding}
            onChange={(value) =>
              this.props.setAttributes({
                padding: value,
              })
            }
            min={0}
            max={50}
            step={1}
          />
          <PanelColorSettings
            title={__("Column Background", "easy-gtblocks")}
            initialOpen={false}
            colorSettings={[
              {
                value: backgroundColor,
                onChange: onChangeBackgroundColor,
                label: __("Background Color", "easy-gtblocks"),
              },
            ]}
          >
            <RangeControl
              label={__(
                "Background Color Opacity",
                "easy-gtblocks"
              )}
              value={opacity}
              onChange={(value) =>
                this.props.setAttributes({
                  opacity: value !== undefined ? value : 50,
                })
              }
              min={0}
              max={100}
              allowReset
            />
            <ToggleControl
              label="Gradient Background"
              checked={bgGradient}
              onChange={() =>
                this.props.setAttributes({
                  bgGradient: !bgGradient,
                })
              }
            />
            {bgGradient && (
              <Fragment>
                <PanelColorSettings
                  title={__("Primary Color", "easy-gtblocks")}
                  initialOpen={false}
                  colorSettings={[
                    {
                      value: backgroundColor,
                      onChange: onChangeBackgroundColor,
                      label: __(
                        "Primary Color",
                        "easy-gtblocks"
                      ),
                    },
                  ]}
                ></PanelColorSettings>
                <PanelColorSettings
                  title={__(
                    "Secondary Color",
                    "easy-gtblocks"
                  )}
                  initialOpen={false}
                  colorSettings={[
                    {
                      label: __(
                        "Secondary Color",
                        "easy-gtblocks"
                      ),
                      value: secondaryBackgroundColor,
                      onChange: onChangeSecondaryBackgroundColor,
                    },
                  ]}
                ></PanelColorSettings>
                <RangeControl
                  label={__(
                    "Color Location 1",
                    "easy-gtblocks"
                  )}
                  value={colorLocation1}
                  min={0}
                  max={100}
                  onChange={(value) =>
                    setAttributes({
                      colorLocation1: value !== undefined ? value : 0,
                    })
                  }
                />
                <RangeControl
                  label={__(
                    "Color Location 2",
                    "easy-gtblocks"
                  )}
                  value={colorLocation2}
                  min={0}
                  max={100}
                  onChange={(value) =>
                    setAttributes({
                      colorLocation2: value !== undefined ? value : 100,
                    })
                  }
                />
              </Fragment>
            )}
            {bgGradient && (
              <RangeControl
                label={__("Gradient Degree", "easy-gtblocks")}
                value={gradientDegree}
                onChange={(value) =>
                  setAttributes({
                    gradientDegree: value !== undefined ? value : 100,
                  })
                }
                min={0}
                max={360}
              />
            )}
            <BaseControl
              className="editor-bg-image-control"
              label={__("Background Image", "easy-gtblocks")}
            >
              <MediaUpload
                title={__(
                  "Select Background Image",
                  "easy-gtblocks"
                )}
                onSelect={this.onSelectImage}
                allowedTypes={["image"]}
                value={backgroundImage}
                render={({ open }) => (
                  <Button isDefault onClick={open}>
                    {!backgroundImage
                      ? __(
                          "Select Background Image",
                          "easy-gtblocks"
                        )
                      : __("Replace image", "easy-gtblocks")}
                  </Button>
                )}
              />
              {backgroundImage && (
                <Button
                  className="uagb-rm-btn"
                  onClick={this.onRemoveImage}
                  isLink
                  isDestructive
                >
                  {__("Remove Image", "easy-gtblocks")}
                </Button>
              )}
            </BaseControl>

            <SelectControl
              label={__("Background Position")}
              value={backgroundPosition}
              onChange={(newBackgroundPosition) =>
                setAttributes({ backgroundPosition: newBackgroundPosition })
              }
              options={[
                { value: "left top", label: __("Left Top") },
                { value: "left center", label: __("Left Center") },
                { value: "left bottom", label: __("Left Bottom") },
                { value: "right top", label: __("Right Top") },
                { value: "right center", label: __("Right Center") },
                { value: "right bottom", label: __("Right Bottom") },
                { value: "center top", label: __("Center Top") },
                { value: "center center", label: __("Center Center") },
                { value: "center bottom", label: __("Center Bottom") },
              ]}
            />
            <SelectControl
              label={__("Background Repeat")}
              value={backgroundRepeat}
              onChange={(newBackgroundRepeat) =>
                setAttributes({ backgroundRepeat: newBackgroundRepeat })
              }
              options={[
                { value: "initial", label: __("Initial") },
                { value: "repeat", label: __("Repeat") },
                { value: "no-repeat", label: __("No-Repeat") },
                { value: "round", label: __("Round") },
                { value: "inherit", label: __("Inherit") },
                { value: "space", label: __("Space") },
                { value: "repeat-y", label: __("Repeat Y") },
                { value: "repeat-x", label: __("Repeat X") },
              ]}
            />
            <SelectControl
              label={__("Background Size")}
              value={backgroundAttachment}
              onChange={(newBackgroundAttachment) =>
                setAttributes({ backgroundAttachment: newBackgroundAttachment })
              }
              options={[
                { value: "fixed", label: __("Fixed") },
                { value: "scroll", label: __("Scroll") },
              ]}
            />
            <SelectControl
              label={__("Background Size")}
              value={backgroundSize}
              onChange={(newBackgroundSize) =>
                setAttributes({ backgroundSize: newBackgroundSize })
              }
              options={[
                { value: "initial", label: __("Initial") },
                { value: "cover", label: __("Cover") },
                { value: "contain", label: __("Contain") },
                { value: "auto", label: __("Auto") },
                { value: "inherit", label: __("Inherit") },
              ]}
            />
          </PanelColorSettings>
        </PanelBody>

        <PanelBody
          title={__("Content", "easy-gtblocks")}
          initialOpen={false}
        >
              <ToggleControl
      label="Image"
      checked={showImage}
      onChange={() =>
      this.props.setAttributes({
          showImage: !showImage,
      })
  }
      />
         <ToggleControl
      label="Name"
      checked={showName}
      onChange={() =>
      this.props.setAttributes({
          showName: !showName,
      })
  }
      />
         <ToggleControl
      label="Designation"
      checked={showDesignation}
      onChange={() =>
      this.props.setAttributes({
          showDesignation: !showDesignation,
      })
  }
      />
         <ToggleControl
      label="Description"
      checked={showDescription}
      onChange={() =>
      this.props.setAttributes({
          showDescription: !showDescription,
      })
  }
      />
          <ToggleControl
      label="Social Icons"
      checked={showSocialIcons}
      onChange={() =>
      this.props.setAttributes({
          showSocialIcons: !showSocialIcons,
      })
  }
      />
         </PanelBody>
         <PanelBody
          title={__("Image", "easy-gtblocks")}
          initialOpen={false}
        >
          <SelectControl
            label={__("Image Shape", "easy-gtblocks")}
            value={imageShape}
            options={imageShapeOptions}
            onChange={(newImageShape) =>
              setAttributes({ imageShape: newImageShape })
            }
          />
          <SelectControl
            label={__("Image Size")}
            value={imageSize}
            onChange={(newImageSize) =>
              setAttributes({ imageSize: newImageSize })
            }
            options={[
              { value: "full", label: __("Full Size") },
              { value: "thumbnail", label: __("Thumbnail") },
              { value: "medium", label: __("Medium") },
              { value: "large", label: __("Large") },
            ]}
          />
          <RangeControl
            label={__("Image Width", "easy-gtblocks")}
            value={imageWidth}
            onChange={(value) =>
              this.props.setAttributes({
                imageWidth: value,
              })
            }
            min={0}
            max={500}
            step={10}
          />
        </PanelBody>
        <PanelBody
          title={__("Typography", "easy-gtblocks")}
          initialOpen={false}
        >
          <PanelBody
            title={__("Title Typography", "easy-gtblocks")}
            initialOpen={false}
          >
            <SelectControl
              label={__("Font Family", "easy-gtblocks")}
              options={fontOptions}
              value={titleFontFamily}
              onChange={(value) => {
                setAttributes({
                  titleFontFamily: value,
                }),
                  loadGoogleFont(value);
              }}
            />
            <RangeControl
              label={__("Font Size", "easy-gtblocks")}
              value={titleFontSize}
              onChange={(value) =>
                this.props.setAttributes({
                  titleFontSize: value,
                })
              }
              min={0}
              max={50}
              step={1}
            />
            <SelectControl
              label={__("Font Weight", "easy-gtblocks")}
              options={fontWeightOptions}
              value={titleFontWeight}
              onChange={(value) =>
                this.props.setAttributes({
                  titleFontWeight: value,
                })
              }
            />
            <RangeControl
              label={__("Line Height", "easy-gtblocks")}
              value={titleLineHeight}
              onChange={(value) =>
                this.props.setAttributes({
                  titleLineHeight: value,
                })
              }
              min={0}
              max={100}
              step={1}
            />
          </PanelBody>
          <PanelBody
            title={__(
              "Designation Typography",
              "easy-gtblocks"
            )}
            initialOpen={false}
          >
            <SelectControl
              label={__("Font Family", "easy-gtblocks")}
              options={fontOptions}
              value={designationFontFamily}
              onChange={(value) => {
                setAttributes({
                  designationFontFamily: value,
                }),
                  loadGoogleFont(value);
              }}
            />
            <RangeControl
              label={__("Font Size", "easy-gtblocks")}
              value={designationFontSize}
              onChange={(value) =>
                this.props.setAttributes({
                  designationFontSize: value,
                })
              }
              min={0}
              max={50}
              step={1}
            />
            <SelectControl
              label={__("Font Weight", "easy-gtblocks")}
              options={fontWeightOptions}
              value={designationFontWeight}
              onChange={(value) =>
                this.props.setAttributes({
                  designationFontWeight: value,
                })
              }
            />
            <RangeControl
              label={__("Line Height", "easy-gtblocks")}
              value={designationLineHeight}
              onChange={(value) =>
                this.props.setAttributes({
                  designationLineHeight: value,
                })
              }
              min={0}
              max={100}
              step={1}
            />
          </PanelBody>
          <PanelBody
            title={__(
              "Description Typography",
              "easy-gtblocks"
            )}
            initialOpen={false}
          >
            <SelectControl
              label={__("Font Family", "easy-gtblocks")}
              options={fontOptions}
              value={descriptionFontFamily}
              onChange={(value) => {
                setAttributes({
                  descriptionFontFamily: value,
                }),
                  loadGoogleFont(value);
              }}
            />
            <RangeControl
              label={__("Font Size", "easy-gtblocks")}
              value={descriptionFontSize}
              onChange={(value) =>
                this.props.setAttributes({
                  descriptionFontSize: value,
                })
              }
              min={0}
              max={50}
              step={1}
            />
            <SelectControl
              label={__("Font Weight", "easy-gtblocks")}
              options={fontWeightOptions}
              value={descriptionFontWeight}
              onChange={(value) =>
                this.props.setAttributes({
                  descriptionFontWeight: value,
                })
              }
            />
            <RangeControl
              label={__("Line Height", "easy-gtblocks")}
              value={descriptionLineHeight}
              onChange={(value) =>
                this.props.setAttributes({
                  descriptionLineHeight: value,
                })
              }
              min={0}
              max={100}
              step={1}
            />
          </PanelBody>
        </PanelBody>

        <PanelBody
          title={__("Spacing", "easy-gtblocks")}
          initialOpen={false}
        >
          <RangeControl
            label={__("Title Bottom Spacing", "easy-gtblocks")}
            value={titleSpacing}
            onChange={(value) =>
              this.props.setAttributes({
                titleSpacing: value,
              })
            }
            min={0}
            max={50}
            step={1}
          />
          <RangeControl
            label={__(
              "Designation Bottom Spacing",
              "easy-gtblocks"
            )}
            value={designationSpacing}
            onChange={(value) =>
              this.props.setAttributes({
                designationSpacing: value,
              })
            }
            min={0}
            max={50}
            step={1}
          />
          <RangeControl
            label={__(
              "Description Bottom Spacing",
              "easy-gtblocks"
            )}
            value={descriptionSpacing}
            onChange={(value) =>
              this.props.setAttributes({
                descriptionSpacing: value,
              })
            }
            min={0}
            max={50}
            step={1}
          />
          <RangeControl
            label={__(
              "Inter Social Icon Spacing",
              "easy-gtblocks"
            )}
            value={socialIconSpacing}
            onChange={(value) =>
              this.props.setAttributes({
                socialIconSpacing: value,
              })
            }
            min={0}
            max={50}
            step={1}
          />
          <RangeControl
            label={__("Image Margin Top", "easy-gtblocks")}
            value={imageMarginTop}
            onChange={(value) =>
              this.props.setAttributes({
                imageMarginTop: value,
              })
            }
            min={0}
            max={200}
            step={1}
          />
          <RangeControl
            label={__("Image Margin Bottom", "easy-gtblocks")}
            value={imageMarginBottom}
            onChange={(value) =>
              this.props.setAttributes({
                imageMarginBottom: value,
              })
            }
            min={0}
            max={200}
            step={1}
          />
        </PanelBody>
        <PanelBody
          title={__("Social", "easy-gtblocks")}
          initialOpen={false}
        >
          <PanelBody
            title={__("Hide Social Icons", "easy-gtblocks")}
            initialOpen={true}
          >
            <ToggleControl
              label="Twitter"
              checked={twitter}
              onChange={() =>
                this.props.setAttributes({
                  twitter: !twitter,
                })
              }
            />
            <ToggleControl
              label="Facebook"
              checked={facebook}
              onChange={() =>
                this.props.setAttributes({
                  facebook: !facebook,
                })
              }
            />
            <ToggleControl
              label="Linkedin"
              checked={linkedin}
              onChange={() =>
                this.props.setAttributes({
                  linkedin: !linkedin,
                })
              }
            />
            <ToggleControl
              label="Instagram"
              checked={instagram}
              onChange={() =>
                this.props.setAttributes({
                  instagram: !instagram,
                })
              }
            />
            <ToggleControl
              label="Email"
              checked={email}
              onChange={() =>
                this.props.setAttributes({
                  email: !email,
                })
              }
            />
            <ToggleControl
              label="Youtube"
              checked={youtube}
              onChange={() =>
                this.props.setAttributes({
                  youtube: !youtube,
                })
              }
            />
            <ToggleControl
              label="Pinterest"
              checked={pinterest}
              onChange={() =>
                this.props.setAttributes({
                  pinterest: !pinterest,
                })
              }
            />
          </PanelBody>
          <PanelColorSettings
            title={__("Colors", "easy-gtblocks")}
            initialOpen={true}
            colorSettings={[
              {
                value: socialIconColor,
                onChange: onChangeSocialIconColor,
                label: __(
                  "Social Icon Color",
                  "easy-gtblocks"
                ),
              },
            ]}
          ></PanelColorSettings>
          <SelectControl
            label={__("Icon Size", "easy-gtblocks")}
            value={iconSize}
            options={iconSizeOptions}
            onChange={(newIconSize) => setAttributes({ iconSize: newIconSize })}
          />
        </PanelBody>
        <PanelColorSettings
          title={__("Color Settings", "easy-gtblocks")}
          initialOpen={false}
          colorSettings={[
            {
              value: borderColor,
              onChange: onChangeBorderColor,
              label: __("Border Color", "easy-gtblocks"),
            },
            {
              value: titleColor,
              onChange: onChangetitleColor,
              label: __("Title Color", "easy-gtblocks"),
            },
            {
              value: designationColor,
              onChange: onChangeDesignationColor,
              label: __("Designation Color", "easy-gtblocks"),
            },
            {
              value: descriptionColor,
              onChange: onChangeDescriptionColor,
              label: __("Description Color", "easy-gtblocks"),
            },
          ]}
        ></PanelColorSettings>
      </InspectorControls>
    );
  }
}
